# GPTConnect

GPTConnect is a Python 🐍 package that simplifies the use of the new functions feature of ChatGPT by OpenAI. It provides an easy-to-use framework for creating and interacting with GPT functions, making your development process smoother and more efficient.

Make sure to star this project if you find it useful! ✨

If you have any ideas, bug reports or suggestions feel free to open an issue or contact me on discord at @**sleepystew**

## 🔧 Features

- 🎉 Simplified and intuitive decorator based system to define GPT functions.
- 🔤 Function groups system that allows for easy integration of multiple commands.
- 🕐 More features coming soon! This package is only in early stages of development.

## 🚀 Install
`pip install GPTConnect`

## Example Usage
[example-simple.py](https://github.com/SleepyStew/gptconnect/blob/master/example-simple.py)
[example-advanced.py](https://github.com/SleepyStew/gptconnect/blob/master/example-advanced.py)
